
# MMScan meta-annotaion & benchmark-samples (beta Version)

## 📄 File Structure

Our MMScan-beta is organized into two main parts: <b>meta-annotaion  & benchmark-samples </b>. We provide the <b>train-split</b> and <b>val-split</b> of our MMScan-beta.

PS: In the original datasets of ScanNet, 3RScan, and Matterport3D, we have divided the combined 5k scans into training, validation, and test sets. Specifically, we provide MmScan meta-annotation and benchmark samples over 4k scans for training and validation purposes. The ids for the scans originate from Matterport3D as `matterport3d/{}/region{}`, from 3RScan as `3rscan/{}`, and from ScanNet as `scannet/{}` respectively.

```
MMScan-beta/
│
├── README.md          
├── MMScan_meta/              
│   ├── MMScan_object_meta.json   # object-level annotation
│   └── MMScan_region_meta.json   # region-level annotation
│   
│
├── MMScan_samples/     # (consists of train/val)        
│   ├── MMScan_QA.json  # 3D question answering benchmark samples 
│   ├── MMScan_VG.json  # 3D visual grounding benchmark samples
│   ├── MMScan_Caption_object.json    # 3D caption benchmark samples (object-level)
│   └── MMScan_Caption_region.json    # 3D caption benchmark samples (region-level)        
│     
├── Data_splits/
│   ├── train-split.json  # id list of scans belonging to train split
│   ├── val-split.json    # id list of scans belonging to val split
│   └── test-split.json   # id list of scans belonging to test split
```
##  📒 Data Format


###  meta-annotation

We provide object-level and region-level annotation for each scan. All the annotations are stored in JSON format, under `meta-annotation/MMScan_object_meta.json` and `meta-annotation/MMScan_region_meta.json`. Each annotation sample is uniquely identified by its corresponding scan_id and object_id or region_id.

1. object-level annotation format

```
{
    "scan_id": str,                            # scan id
    "object_id": int,                          # id of the object in the scan, in accord with embodiedScan
    "object_type": str,                        # type of the object
    "original_description": str,               # intial annotation from GPT
    "modified_description_en": str             # modified annotation from human
}
```
2. region-level annotation format

```
{
    "scan_id": str,                                      # scan id
    "region_id": str,                                    # region ID in the scan
    "object_ids": list of int (object id)                # all objects in the region
    "OO-relation": dict {(object1,object2): relation}    # object-object functional relationship
    "OR-releation1": dict {object: text}                 # single object relationship with the region
    "OR-releation2": dict {list of object: text}         # multi objects relationship with the region
    "R-description": dict {aspect: text}                 # features of the region
}
```
###  benchmark-samples

Under `MMScan_samples/MMScan_QA.json`, `MMScan_samples/MMScan_VG.json` and `MMScan_Caption_object.json`/`MMScan_Caption_region.json`, we provide separately the samples of 3D Question Answering, 3D Visual Grounding and 3D Caption Benchmark, all samples of scans are stored in a JSON Format.(`MMScan_samples/{task_name}.json`)

Using the provided train/val scan ids split (located in `./Data_split/`), we splits the samples into train and val sets, and the data format of `MMScan_samples/{task_name}.json` is : { "train" : [ data1, ... , dataN, ... ] , "val" : [ data1, ... , dataN, ... ] }


<b> Notice: Some data should not be visible to the model (gt) </b>

1. 3D question answering sample



```
{
        "sub_class": str,                        # the sub-class of the sample 
        "scan_id": str,                          # the scan id
        "question": str,                         # the question (prompt)
        "answers": list of str,                  # the answer candidates (gt)
        "object_ids": list of int,               # the object ids involved (gt)
        "object_names": list of str,             # the object names involved (gt)
        "input_bboxes_id": list of int/ None,    # Id of the input bounding boxes (prompt)
        "input_bboxes": list of 9DOF / None,            # the input bounding boxes (prompt)
        "output_bboxes_id": list of int/ None,   # Id of the output bounding boxes (gt)      
        "output_bboxes": list of 9DOF / None,    # the output bounding boxes (gt)
        "ID": str                                # the unique id of the sample
}
```
 PS: For this version, all output_bboxes and output_bboxes_id are null since we do not require model to outpout bounding boxes in Question Answering task.

2. 3D visual grounding sample

```
{
        "sub_class": str,                        # the sub-class of the sample
        "scan_id": str,                          # the scan id
        "text": str,                             # the grounding text
        "target": list of str                    # the type of target objects (gt)
        "target_id": list of int,                # the id of target objects (gt)
        "distractor_ids": list of int,           # the id of distractor (same type as target)
        "anchors": list of str                   # the type of anchor objects
        "anchor_ids": list of int                # the id of anchor objects
        "tokens_positive": dict                  # pos index of token positives in the grounding text (gt)   
        "ID": str                                # the unique id of the sample
    }
```
More explanation of the "tokens_positive": For each target object/ anchor object, we stores its relevant words in the grounding text in a format of a list of indices where the word appearing. For example, if the grounding text is "The red chair near the wooden table.", and the target object is "chair" with id 1, and the anchor object is "table" with id 2, the "tokens_positive" will be { 1: [ [ 0, 13 ] ], 2: [ [ 19, 35 ] ] }, since the word "The red chair" appears in the first 13 characters of the text, and the word "the wooden table" appears in characters 19 through 35.

3. 3D Caption

We provide the all objects and regions caption samples for each scan. Both are in a JSON format.
```
# object caption
{
    "scan_id": str,                             # scan id
    "object_id": int,                           # id of the object in the scan, in accord with embodiedScan
    "object_type": str,                         # type of the object
    "caption": str                              # caption of the object 
}

# region caption
{
    "scan_id": str,                             # scan id
    "object_list": list of int,                 # ids of objects in the region
    "region_id": int                            # id of region in the scan
    "region_type": str,                         # type of the region
    "region_caption": str                       # caption of the region
}


``` T